==> hive-apache-3.0.0-4-sources.jar: org/apache/hadoop/hive/metastore/events/OpenTxnEvent.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.hadoop.hive.metastore.events;

import org.apache.hadoop.classification.InterfaceAudience;
import org.apache.hadoop.classification.InterfaceStability;
import org.apache.hadoop.hive.metastore.IHMSHandler;
import io.prestosql.hive.$internal.com.google.common.collect.Lists;
import java.util.List;

/**
 * OpenTxnEvent
 * Event generated for open transaction event.
 */
@InterfaceAudience.Public
@InterfaceStability.Stable
public class OpenTxnEvent extends ListenerEvent {
  private List<Long> txnIds;

  /**
   * @param txnIds List of unique identification for the transaction just opened.
   * @param handler handler that is firing the event
   */
  public OpenTxnEvent(List<Long> txnIds, IHMSHandler handler) {
    super(true, handler);
    this.txnIds = Lists.newArrayList(txnIds);
  }

  /**
   * @return List<Long> txnIds
   */
  public List<Long> getTxnIds() {
    return txnIds;
  }
}

==> hive-apache-3.1.2-13-sources.jar: org/apache/hadoop/hive/metastore/events/OpenTxnEvent.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.hadoop.hive.metastore.events;

import org.apache.hadoop.classification.InterfaceAudience;
import org.apache.hadoop.classification.InterfaceStability;
import org.apache.hadoop.hive.metastore.IHMSHandler;
import io.trino.hive.$internal.com.google.common.collect.Lists;
import java.util.List;

/**
 * OpenTxnEvent
 * Event generated for open transaction event.
 */
@InterfaceAudience.Public
@InterfaceStability.Stable
public class OpenTxnEvent extends ListenerEvent {
  private List<Long> txnIds;

  /**
   * @param txnIds List of unique identification for the transaction just opened.
   * @param handler handler that is firing the event
   */
  public OpenTxnEvent(List<Long> txnIds, IHMSHandler handler) {
    super(true, handler);
    this.txnIds = Lists.newArrayList(txnIds);
  }

  /**
   * @return List<Long> txnIds
   */
  public List<Long> getTxnIds() {
    return txnIds;
  }
}
